# -*- coding: utf-8 -*-

import datetime

from django.db.models import Q

from kinder.core.direct.models import DRS
from kinder.core.group import GroupStatusEnum, Pupil
from gisdo.utils import DateMixin


def get_193_filter(**kwargs):
    """Фильтр для показателя 19.3
    - направния в статусе "Направлен в ДОУ", "Заключение договора"
    """

    return Q(
        Q(group__unit_id=kwargs.get("unit").id) &
        Q(status__code__in=(DRS.REGISTER, DRS.DOGOVOR))
    )


def get_34_filter(**kwargs):
    """Фильтр для показателя 34
    - направления в статусе "Направлен в ДОУ", "Заключение договора", "зачислен"
    - дата создания направления: [01.01.2015 - текущая дата],
    т.е текущий календарный год
    """
    today_ = datetime.date.today()
    return Q(status__code__in=[DRS.ACCEPT, DRS.DOGOVOR, DRS.REGISTER],
             date__range=(datetime.date(today_.year, 1, 1), today_))
